@@ -2,9 +2,8 @@
 
 import asyncclick as click
 import json
-import yaml
 
-from distkv.util import yprint, NotGiven
+from distkv.util import yprint, NotGiven, yload, P, Path
 
 import logging
 
@@ -18,23 +17,18 @@ async def cli():
 
 
 @cli.command()
-@click.option(
-    "-s", "--script", type=click.File(mode="w", lazy=True), help="Save the script here"
-)
-@click.option(
-    "-S", "--schema", type=click.File(mode="w", lazy=True), help="Save the schema here"
-)
-@click.option(
-    "-y", "--yaml", "yaml_", is_flag=True, help="Write schema as YAML. Default: JSON."
-)
-@click.argument("path", nargs=-1)
+@click.option("-s", "--script", type=click.File(mode="w", lazy=True), help="Save the script here")
+@click.option("-S", "--schema", type=click.File(mode="w", lazy=True), help="Save the schema here")
+@click.option("-y", "--yaml", "yaml_", is_flag=True, help="Write schema as YAML. Default: JSON.")
+@click.argument("path", nargs=1)
 @click.pass_obj
 async def get(obj, path, script, schema, yaml_):
     """Read type checker information"""
+    path = P(path)
     if not path:
         raise click.UsageError("You need a non-empty path.")
     res = await obj.client._request(
-        action="get_internal", path=("type",) + path, iter=False, nchain=obj.meta
+        action="get_internal", path=Path("type") + path, iter=False, nchain=obj.meta
     )
     r = res.value
     if not obj.meta:
@@ -52,27 +46,20 @@ async def get(obj, path, script, schema, yaml_):
 @cli.command("set")
 @click.option("-g", "--good", multiple=True, help="Example for passing values")
 @click.option("-b", "--bad", multiple=True, help="Example for failing values")
-@click.option(
-    "-d", "--data", type=click.File(mode="r"), help="Load metadata from this YAML file."
-)
-@click.option(
-    "-s", "--script", type=click.File(mode="r"), help="File with the checking script"
-)
-@click.option(
-    "-S", "--schema", type=click.File(mode="r"), help="File with the JSON schema"
-)
-@click.option(
-    "-y", "--yaml", "yaml_", is_flag=True, help="load the schema as YAML. Default: JSON"
-)
-@click.argument("path", nargs=-1)
+@click.option("-d", "--data", type=click.File(mode="r"), help="Load metadata from this YAML file.")
+@click.option("-s", "--script", type=click.File(mode="r"), help="File with the checking script")
+@click.option("-S", "--schema", type=click.File(mode="r"), help="File with the JSON schema")
+@click.option("-y", "--yaml", "yaml_", is_flag=True, help="load the schema as YAML. Default: JSON")
+@click.argument("path", nargs=1)
 @click.pass_obj
 async def set_(obj, path, good, bad, script, schema, yaml_, data):
     """Write type checker information."""
-    if not path:
+    path = P(path)
+    if not len(path):
         raise click.UsageError("You need a non-empty path.")
 
     if data:
-        msg = yaml.safe_load(data)
+        msg = yload(data)
     else:
         msg = {}
     chain = NotGiven
@@ -97,7 +84,7 @@ async def set_(obj, path, good, bad, script, schema, yaml_, data):
         raise click.UsageError("Missing schema")
     elif schema:
         if yaml_:
-            msg["schema"] = yaml.safe_load(schema)
+            msg["schema"] = yload(schema)
         else:
             msg["schema"] = json.load(schema)
 
@@ -112,7 +99,7 @@ async def set_(obj, path, good, bad, script, schema, yaml_, data):
     res = await obj.client._request(
         action="set_internal",
         value=msg,
-        path=("type",) + path,
+        path=Path("type") + path,
         iter=False,
         nchain=obj.meta,
         **({} if chain is NotGiven else {"chain": chain})
@@ -123,41 +110,40 @@ async def set_(obj, path, good, bad, script, schema, yaml_, data):
 
 @cli.command()
 @click.option("-R", "--raw", is_flag=True, help="Print just the path.")
-@click.option(
-    "-t", "--type", multiple=True, help="Type to link to. Multiple for subytpes."
-)
+@click.option("-t", "--type", "type_", help="Type path to link to.")
 @click.option("-d", "--delete", help="Use to delete this mapping.")
-@click.argument("path", nargs=-1)
+@click.argument("path", nargs=1)
 @click.pass_obj
-async def match(obj, path, type, delete, raw):  # pylint: disable=redefined-builtin
+async def match(obj, path, type_, delete, raw):  # pylint: disable=redefined-builtin
     """Match a type to a path (read, if no type given)"""
-    if not path:
+    path = P(path)
+    if not len(path):
         raise click.UsageError("You need a non-empty path.")
-    if type and delete:
+    if type_ and delete:
         raise click.UsageError("You can't both set and delete a path.")
-    if raw and (type or delete):
+    if raw and (type_ or delete):
         raise click.UsageError("You can only print the raw path when reading a match.")
 
     if delete:
-        res = await obj.client._request(action="delete_internal", path=("type",) + path)
+        res = await obj.client._request(action="delete_internal", path=Path("type") + path)
         if obj.meta:
             yprint(res, stream=obj.stdout)
         return
 
     msg = {}
-    if type:
-        msg["type"] = type
+    if type_:
+        msg["type"] = P(type_)
         act = "set_internal"
     elif delete:
         act = "delete_internal"
     else:
         act = "get_internal"
     res = await obj.client._request(
-        action=act, value=msg, path=("match",) + path, iter=False, nchain=obj.meta
+        action=act, value=msg, path=Path("match") + path, iter=False, nchain=obj.meta
     )
     if obj.meta:
         yprint(res, stream=obj.stdout)
-    elif type or delete:
+    elif type_ or delete:
         pass
     else:
         print(" ".join(str(x) for x in res.type), file=obj.stdout)
