@@ -41,16 +41,22 @@ logger = logging.getLogger(__name__)
     hidden=True,
 )
 @click.option(
-    "-e",
-    "--eval",
-    "eval_",
+    "-e", "--eval", "eval_", is_flag=True, help="The 'init' value shall be evaluated.", hidden=True
+)
+@click.option(
+    "-a",
+    "--auth",
+    "--authoritative",
     is_flag=True,
-    help="The 'init' value shall be evaluated.",
-    hidden=True,
+    help="Data in this file is complete: mark anything missing as known even if not.",
+)
+@click.option(
+    "-f", "--force", is_flag=True, help="Force 'successful' startup even if data are missing."
 )
 @click.argument("name", nargs=1)
+@click.argument("nodes", nargs=-1)
 @click.pass_obj
-async def cli(obj, name, load, save, init, incremental, eval_):
+async def cli(obj, name, load, save, init, incremental, eval_, auth, force, nodes):
     """
     This command starts a DistKV server. It defaults to connecting to the local Serf
     agent.
@@ -65,6 +71,17 @@ async def cli(obj, name, load, save, init, incremental, eval_):
 
     This command requires a unique NAME argument. The name identifies this
     server on the network. Never start two servers with the same name!
+
+    You can force the server to fetch its data from a specific node, in
+    case some data are corrupted. (This should never be necessary.)
+
+    A server will refuse to start up as long as it knows about missing
+    entries. Use the 'force' flag to disable that. You should disable
+    any clients which use this server until the situation is resolved!
+
+    An auhthoritative server doesn't have missing data in its storage by
+    definition. This flag is used in the 'run' script when loading from a
+    file.
     """
 
     kw = {}
@@ -77,9 +94,16 @@ async def cli(obj, name, load, save, init, incremental, eval_):
 
     from distkv.util import as_service
 
+    if load and nodes:
+        raise click.UsageError("Either read from a file or fetch from a node. Not both.")
+    if auth and force:
+        raise click.UsageError("Using both '-a' and '-f' is redundant. Choose one.")
+
     async with as_service(obj) as evt:
         s = Server(name, cfg=obj.cfg, **kw)
         if load is not None:
-            await s.load(path=load, local=True)
+            await s.load(path=load, local=True, authoritative=auth)
+        if nodes:
+            await s.fetch_data(nodes, authoritative=auth)
 
-        await s.serve(log_path=save, log_inc=incremental, ready_evt=evt)
+        await s.serve(log_path=save, log_inc=incremental, force=force, ready_evt=evt)
