@@ -23,6 +23,12 @@ from .util import NotGiven, combine_dict, attrdict, P, Path, logger_for, spawn,
 
 from .exceptions import ServerError
 from .obj import AttrClientEntry, ClientRoot
+from distmqtt.utils import create_queue
+
+try:
+    ClosedResourceError = anyio.exceptions.ClosedResourceError
+except AttributeError:
+    ClosedResourceError = anyio.ClosedResourceError
 
 import logging
 
@@ -168,6 +174,13 @@ class CallAdmin:
                 await sc.cancel()
                 return res
 
+    async def _pinger(self):
+        t = self._runner.ok_after or 10
+        await anyio.sleep(t / 2)
+        while True:
+            await self._runner.state.ping()
+            await anyio.sleep(t * 5)
+
     async def _changed_code(self, code):
         """
         Kill the job if the underlying code has changed
@@ -502,7 +515,7 @@ class RunnerEntry(AttrClientEntry):
                 data = combine_dict(self.data or {}, code.value.get("default", {}), deep=True)
 
                 if code.is_async:
-                    data["_info"] = self._q = anyio.create_queue(QLEN)
+                    data["_info"] = self._q = create_queue(QLEN)
                 data["_client"] = self.root.client
                 data["_cfg"] = self.root.client._cfg
                 data["_cls"] = _CLASSES
@@ -563,7 +576,7 @@ class RunnerEntry(AttrClientEntry):
                 async with anyio.move_on_after(2, shield=True):
                     try:
                         await state.save()
-                    except anyio.exceptions.ClosedResourceError:
+                    except ClosedResourceError:
                         pass
                     except ServerError:
                         logger.exception("Could not save")
@@ -696,6 +709,7 @@ class StateEntry(AttrClientEntry):
     Arguments:
       started (float): timestamp when the job was last started
       stopped (float): timestamp when the job last terminated
+      pinged (float): timestamp when the state was last verified by the runner
       result (Any): the code's return value
       node (str): the node running this code
       backoff (float): on error, the multiplier to apply to the restart timeout
@@ -703,10 +717,11 @@ class StateEntry(AttrClientEntry):
       reason (str): reason why (not) starting
     """
 
-    ATTRS = "started stopped computed reason result node backoff".split()
+    ATTRS = "started stopped pinged computed reason result node backoff".split()
 
     started = 0  # timestamp
     stopped = 0  # timestamp
+    pinged = 0  # timestamp
     node = None  # on which the code is currently running
     result = NotGiven
     backoff = 0
@@ -736,10 +751,15 @@ class StateEntry(AttrClientEntry):
         )
         await self.save()
 
+    async def ping(self):
+        if self.node != self.root.name:
+            raise RuntimeError("Not our state!")
+        self.pinged = time.time()
+        await self.save()
+
     async def stale(self):
         self.stopped = time.time()
-        node = self.node
-        self.node = None
+        node, self.node = self.node, None
         self.backoff = min(20, self.backoff + 2)
         await self.root.runner.err.record_error(
             "run",
@@ -1031,7 +1051,7 @@ class AnyRunnerRoot(_BaseRunnerRoot):
         ) as act:
             self._act = act
 
-            age_q = anyio.create_queue(10)
+            age_q = create_queue(10)
             await self.spawn(self._age_killer, age_q)
 
             psutil.cpu_percent(interval=None)
@@ -1187,7 +1207,7 @@ class SingleRunnerRoot(_BaseRunnerRoot):
 
     async def _run_actor(self):
         async with anyio.create_task_group() as tg:
-            age_q = anyio.create_queue(1)
+            age_q = create_queue(1)
 
             async with ClientActor(self.client, self.name, topic=self.group, cfg=self._cfg) as act:
                 self._act = act
